/*
 * Copyright (c) 2010-2011, The MiCode Open Source Community (www.micode.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.micode.notes.tool;

/**
 * 该类包含了与 Google 任务（GTask）相关的 JSON 字符串常量，
 * 用于在处理 GTask 数据交互时作为键名使用，同时也定义了一些特定文件夹名称和元数据相关的常量。
 */
public class GTaskStringUtils {

    // 表示动作 ID 的 JSON 键名
    public final static String GTASK_JSON_ACTION_ID = "action_id";

    // 表示动作列表的 JSON 键名
    public final static String GTASK_JSON_ACTION_LIST = "action_list";

    // 表示动作类型的 JSON 键名
    public final static String GTASK_JSON_ACTION_TYPE = "action_type";

    // 表示创建动作类型的 JSON 值
    public final static String GTASK_JSON_ACTION_TYPE_CREATE = "create";

    // 表示获取所有数据动作类型的 JSON 值
    public final static String GTASK_JSON_ACTION_TYPE_GETALL = "get_all";

    // 表示移动动作类型的 JSON 值
    public final static String GTASK_JSON_ACTION_TYPE_MOVE = "move";

    // 表示更新动作类型的 JSON 值
    public final static String GTASK_JSON_ACTION_TYPE_UPDATE = "update";

    // 表示创建者 ID 的 JSON 键名
    public final static String GTASK_JSON_CREATOR_ID = "creator_id";

    // 表示子实体的 JSON 键名
    public final static String GTASK_JSON_CHILD_ENTITY = "child_entity";

    // 表示客户端版本的 JSON 键名
    public final static String GTASK_JSON_CLIENT_VERSION = "client_version";

    // 表示任务是否完成的 JSON 键名
    public final static String GTASK_JSON_COMPLETED = "completed";

    // 表示当前列表 ID 的 JSON 键名
    public final static String GTASK_JSON_CURRENT_LIST_ID = "current_list_id";

    // 表示默认列表 ID 的 JSON 键名
    public final static String GTASK_JSON_DEFAULT_LIST_ID = "default_list_id";

    // 表示是否删除的 JSON 键名
    public final static String GTASK_JSON_DELETED = "deleted";

    // 表示目标列表的 JSON 键名
    public final static String GTASK_JSON_DEST_LIST = "dest_list";

    // 表示目标父实体的 JSON 键名
    public final static String GTASK_JSON_DEST_PARENT = "dest_parent";

    // 表示目标父实体类型的 JSON 键名
    public final static String GTASK_JSON_DEST_PARENT_TYPE = "dest_parent_type";

    // 表示实体增量的 JSON 键名
    public final static String GTASK_JSON_ENTITY_DELTA = "entity_delta";

    // 表示实体类型的 JSON 键名
    public final static String GTASK_JSON_ENTITY_TYPE = "entity_type";

    // 表示获取已删除数据的 JSON 键名
    public final static String GTASK_JSON_GET_DELETED = "get_deleted";

    // 表示 ID 的 JSON 键名
    public final static String GTASK_JSON_ID = "id";

    // 表示索引的 JSON 键名
    public final static String GTASK_JSON_INDEX = "index";

    // 表示最后修改时间的 JSON 键名
    public final static String GTASK_JSON_LAST_MODIFIED = "last_modified";

    // 表示最新同步点的 JSON 键名
    public final static String GTASK_JSON_LATEST_SYNC_POINT = "latest_sync_point";

    // 表示列表 ID 的 JSON 键名
    public final static String GTASK_JSON_LIST_ID = "list_id";

    // 表示列表集合的 JSON 键名
    public final static String GTASK_JSON_LISTS = "lists";

    // 表示名称的 JSON 键名
    public final static String GTASK_JSON_NAME = "name";

    // 表示新 ID 的 JSON 键名
    public final static String GTASK_JSON_NEW_ID = "new_id";

    // 表示备注的 JSON 键名
    public final static String GTASK_JSON_NOTES = "notes";

    // 表示父实体 ID 的 JSON 键名
    public final static String GTASK_JSON_PARENT_ID = "parent_id";

    // 表示前一个兄弟实体 ID 的 JSON 键名
    public final static String GTASK_JSON_PRIOR_SIBLING_ID = "prior_sibling_id";

    // 表示结果的 JSON 键名
    public final static String GTASK_JSON_RESULTS = "results";

    // 表示源列表的 JSON 键名
    public final static String GTASK_JSON_SOURCE_LIST = "source_list";

    // 表示任务集合的 JSON 键名
    public final static String GTASK_JSON_TASKS = "tasks";

    // 表示类型的 JSON 键名
    public final static String GTASK_JSON_TYPE = "type";

    // 表示组类型的 JSON 值
    public final static String GTASK_JSON_TYPE_GROUP = "GROUP";

    // 表示任务类型的 JSON 值
    public final static String GTASK_JSON_TYPE_TASK = "TASK";

    // 表示用户的 JSON 键名
    public final static String GTASK_JSON_USER = "user";

    // MIUI 笔记文件夹前缀
    public final static String MIUI_FOLDER_PREFFIX = "[MIUI_Notes]";

    // 默认文件夹名称
    public final static String FOLDER_DEFAULT = "Default";

    // 通话笔记文件夹名称
    public final static String FOLDER_CALL_NOTE = "Call_Note";

    // 元数据文件夹名称
    public final static String FOLDER_META = "METADATA";

    // 元数据头部 Google 任务 ID
    public final static String META_HEAD_GTASK_ID = "meta_gid";

    // 元数据头部笔记信息
    public final static String META_HEAD_NOTE = "meta_note";

    // 元数据头部数据信息
    public final static String META_HEAD_DATA = "meta_data";

    // 元数据笔记名称，提示不要更新和删除
    public final static String META_NOTE_NAME = "[META INFO] DON'T UPDATE AND DELETE";
}